#
# spec file for package ghc-cmdargs
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cmdargs
Name:           ghc-%{pkg_name}
Version:        0.10.20
Release:        bp153.1.20
Summary:        Command line argument processing
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-transformers-devel

%description
This library provides an easy way to define command line parsers. Most users
will want to use the "System.Console.CmdArgs.Implicit" module, whose
documentation contains an example.

* "System.Console.CmdArgs.Explicit" provides a way to write command line
parsers for both single mode programs (most programs) and multiple mode
programs (e.g. darcs or cabal). Parsers are defined by constructing a data
structure.

* "System.Console.CmdArgs.Implicit" provides a way to concisely define command
line parsers, up to three times shorter than getopt. These parsers are
translated into the Explicit data type.

* "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity with
existing getopt parsers, mapping to the Explicit data type.

For a general reference on what command line flags are commonly used, see
<http://www.faqs.org/docs/artu/ch10s05.html>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.txt README.md

%changelog
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Mon May 14 2018 psimons@suse.com
- Update cmdargs to version 0.10.20.
    [#54], use the getopt data types from base
    [#47], ensure Semigroup instance on all GHC versions
    [#47], GHC 8.4 compatibility
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 0.10.17 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.10.16 with cabal2obs.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.10.15 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.10.14 revision 0 with cabal2obs.
* Wed Feb 17 2016 mimi.vx@gmail.com
- update to 0.10.14
  * ensure correct line breaks in HTML help output
  * preserve manual \n in help messages
  * reformat the README
* Tue May 26 2015 mimi.vx@gmail.com
- update to 0.10.13
  * support Ratio in some places
* Sat Nov 22 2014 mimi.vx@gmail.com
- add group to devel package
* Sun Nov 16 2014 mimi.vx@gmail.com
- initial commit
